<?php

namespace Smsto\Hubspot\Jobs;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldBeUnique;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Crypt;
use Illuminate\Support\Str;
use Smsto\Hubspot\Lib\UrlHelper;
use Smsto\Hubspot\Models\Settings;

class SendJob implements ShouldQueue
{
    use Dispatchable, InteractsWithQueue, Queueable, SerializesModels;

    /**
     * The validated data
     */
    protected $validated;

    /**
     * Create a new job instance.
     *
     * @param array $validated
     * @param string $api_key
     * @return void
     */
    public function __construct(array $validated)
    {
        $this->validated = $validated;
    }

    /**
     * Execute the job.
     *
     * @return void
     */
    public function handle()
    {
        $validated = $this->validated;

        $settings = Settings::where([
            'app_id' => config('hubspot.app_id'),
            'hub_id' => $validated['origin']['portalId']
        ])->first();

        $validated['inputFields']['sender_id'] = isset($validated['inputFields']['sender_id']) ? $validated['inputFields']['sender_id'] : $settings->sender_id;

        $message = $validated["inputFields"]["message"];
        $detectedLinks = UrlHelper::detectLink($message);
        foreach ($detectedLinks['urls'] as $url) {
            $shorlink_response = Http::acceptJson()->withToken($settings->api_key)->post('https://sms.to/api/v1/shortlink', [
                "name" => 'hubspot_' . $validated['origin']['portalId'],
                "url" => $url,
            ]);
            $shortlink = $shorlink_response->json();
            if (isset($shortlink["success"]) && $shortlink["success"]) {
                $message = Str::replace($url, $shortlink["data"]["fullLink"], $message);
            }
        }
        $validated["inputFields"]["message"] = Str::replace("{{optout}}", "{optout}", $message);
        
        $validated["inputFields"]["callback_url"] = route('hubspot.api.smsto.callback', ['settings' => Crypt::encryptString($settings->id), 'associatedObjectId' => $validated['object']['objectId']]);

        $api_key = $settings->api_key;
        $response = Http::withHeaders(['X-Smsto-Integration-Name' => 'hubspot'])->withToken($api_key)->asJson()->acceptJson()->post('https://api.sms.to/sms/send', $validated['inputFields']);
        //$response = json_decode($response, true);
    }
}
