<?php

namespace Smsto\Hubspot\Lib;

use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Storage;

class UrlHelper
{
    public static function parse($content)
    {
        $content = [
            'content' => $content
        ];
        return self::exec('detect-urls', $content);
    }

    public static function buildShellArgs($argument)
    {
        $data = [];
        foreach($argument as $field => $value)
        {
            if(is_string($value))
            {
                $value = '"' . $value . '"';
            }
            elseif(is_bool($value))
            {
                $value = $value ? 'true' : 'false';
            }
            $data[] = '--' . $field . '=' . $value;
        }
        return implode(' ', $data);
    }

    public static function buildCommand($command, $arguments)
    {
        return $command . ' ' . $arguments;
    }

    public static function exec($command, $arguments)
    {
        $command = self::buildCommand(Storage::path($command), self::buildShellArgs($arguments));
        $output = shell_exec($command);
        $data = json_decode($output, true);
        if($data)
        {
            return $data;
        }
        return $output;
    }

    public static function run($host, $port)
    {
        $argument = [
            'host' => $host,
            'port' => $port,
        ];
        $output = self::exec('detect-urls', $argument);
        echo $output;
    }

    public static function detectLink($content, $validateUrls = false)
    {
        $linkDetector = "https://detect-urls.toolbox.intergo.co/";        
        try {
            $responseContent = Http::post($linkDetector, [
                "content" => $content,
            ])->body();
            return json_decode($responseContent, true);
        } catch (\Exception $e)
        {
            return self::parse($content);
        }
    }

    /**
     * Extract URLs for a string.
     *
     * @param string $text
     * @return array
     */
    public static function extractURLs(string $text)
    {
        $detectedURLs = UrlHelper::detectLink($text);
        if (!empty($detectedURLs['urls'])) {
            return $detectedURLs['urls'];
        }

        return [];
    }

    /**
     * @param string $text
     * @return array|mixed
     *
     * @author Sujit Baniya <sujit@intergo.com.cy>
     * @timestamp: 2021-11-08 12:01
     */
    public static function extractEmails(string $text)
    {
        $detectedURLs = UrlHelper::detectLink($text);
        if (!empty($detectedURLs['emails'])) {
            return $detectedURLs['emails'];
        }

        return [];
    }

    /**
     * @param string $text
     * @return int
     *
     * @author Sujit Baniya <sujit@intergo.com.cy>
     * @timestamp: 2021-11-08 12:01
     */
    public static function totalUrls(string $text)
    {
        $detectedURLs = UrlHelper::detectLink($text);
        if (!empty($detectedURLs['total_urls'])) {
            return $detectedURLs['total_urls'];
        }

        return 0;
    }

    public static function statelessAssetUrl($file)
    {
        $path = cdn($file);
        $path = str_replace("http://", "//", $path);
        $path = str_replace("https://", "//", $path);

        return $path;
    }
}
